<?php
/**
 * About setup
 *
 * @package Xclusive
 */

if ( ! function_exists( 'country_inn_about_setup' ) ) :

	/**
	 * About setup.
	 *
	 * @since 1.0.0
	 */
	function country_inn_about_setup() {

		include_once( ABSPATH . 'wp-admin/includes/plugin.php' );
		if ( is_plugin_active( 'one-click-demo-import/one-click-demo-import.php' ) ):

		    $url =  admin_url( 'themes.php?page=pt-one-click-demo-import' );

		else:

		     $url = admin_url();

		endif;

		$config = array(

			// Welcome content.
			'welcome_content' => sprintf( esc_html__( '%1$s is now installed and ready to use. Thank you for choosing Country Inn Pro for your Website. Please follow theme documentation properly to know how to use Country Inn Pro.', 'country-inn' ), 'Country Inn Pro' ),

			// Tabs.
			'tabs' => array(
				'getting-started' => esc_html__( 'Getting Started', 'country-inn' ),
				'free_pro' => esc_html__( 'Free Vs Pro', 'country-inn' ),
				'demos'=> esc_html__( 'Multiple Demos', 'country-inn' ),
				),

			// Quick links.
			'quick_links' => array(
                'theme_url' => array(
                    'text' => esc_html__( 'Theme Details', 'country-inn' ),
                    'url'  => 'https://xclusivethemes.com/themes/country-inn-pro/',
                    'button' => 'primary',
                ),
                'theme_demo' => array(
                    'text' => esc_html__( 'Demo', 'country-inn' ),
                    'url'  => 'https://xclusivethemes.com/demo/country-inn-pro/',
                    'button' => 'primary',
                ),
                'documentation' => array(
                    'text' => esc_html__( 'Documentation', 'country-inn' ),
                    'url'  => 'https://doc.xclusivethemes.com/country-inn-pro/',
                    'button' => 'primary',
                ),
                'support' => array(
                    'text' => esc_html__( 'Support', 'country-inn' ),
                    'url'  => 'https://www.xclusivethemes.com/supports/',
                    'button' => 'primary',
                ),
            ),

			// Getting started.
			'getting_started' => array(
				'one' => array(
					'title'       => esc_html__( 'Theme Documentation', 'country-inn' ),
					'icon'        => 'dashicons dashicons-format-aside',
					'description' => esc_html__( 'Please check our full documentation for detailed information on how to setup and customize the theme.', 'country-inn' ),
					'button_text' => esc_html__( 'View Documentation', 'country-inn' ),
					'button_url'  => 'http://doc.xclusivethemes.com/country-inn-pro/',
					'button_type' => 'primary',
					'is_new_tab'  => true,
					),
				'two' => array(
					'title'       => esc_html__( 'Static Front Page', 'country-inn' ),
					'icon'        => 'dashicons dashicons-admin-generic',
					'description' => esc_html__( 'To achieve custom home page other than blog listing, you need to create and set static front page.', 'country-inn' ),
					'button_text' => esc_html__( 'Static Front Page', 'country-inn' ),
					'button_url'  => admin_url( 'customize.php?autofocus[section]=static_front_page' ),
					'button_type' => 'primary',
					),
				'three' => array(
					'title'       => esc_html__( 'Theme Options', 'country-inn' ),
					'icon'        => 'dashicons dashicons-admin-customizer',
					'description' => esc_html__( 'Theme uses Customizer API for theme options. Using the Customizer you can easily customize different aspects of the theme.', 'country-inn' ),
					'button_text' => esc_html__( 'Customize', 'country-inn' ),
					'button_url'  => wp_customize_url(),
					'button_type' => 'primary',
					),
				'four' => array(
					'title'       => esc_html__( 'Demo Content', 'country-inn' ),
					'icon'        => 'dashicons dashicons-layout',
					'description' => sprintf( esc_html__( 'To import sample demo content, %1$s plugin should be installed and activated. After plugin is activated, visit Import Demo Data menu under Appearance.', 'country-inn' ), esc_html__( 'One Click Demo Import', 'country-inn' ) ),
					'button_text' => esc_html__( 'Demo Import', 'country-inn' ),
					'button_url'  => $url,
					'button_type' => 'primary',
					),
				'five' => array(
					'title'       => esc_html__( 'Theme Preview', 'country-inn' ),
					'icon'        => 'dashicons dashicons-welcome-view-site',
					'description' => esc_html__( 'You can check out the theme demos for reference to find out what you can achieve using the theme and how it can be customized.', 'country-inn' ),
					'button_text' => esc_html__( 'View Demo', 'country-inn' ),
					'button_url'  => 'http://xclusivethemes.com/demo/country-inn-pro',
					'button_type' => 'primary',
					'is_new_tab'  => true,
					),
                'six' => array(
                    'title'       => esc_html__( 'Contact Support', 'country-inn' ),
                    'icon'        => 'dashicons dashicons-sos',
                    'description' => esc_html__( 'Got theme support question or found bug or got some feedbacks? Best place to ask your query is the dedicated Support forum for the theme.', 'country-inn' ),
                    'button_text' => esc_html__( 'Contact Support', 'country-inn' ),
                    'button_url'  => 'https://xclusivethemes.com/contact-us/',
					'button_type' => 'primary',
                    'is_new_tab'  => true,
                ),
				),

			// Free vs pro array.
		    'free_pro' => array(
			    array(
				    'title'       => __( 'Custom Widgets', 'country-inn' ),
				    'desc' => __( 'Added custom Widgets', 'country-inn' ),
				    'free'  => __('1+ Available','country-inn'),
				    'pro'   => __('7+ Available','country-inn'),
			    ),
			    array(
				    'title'       => __( 'Support Forum', 'country-inn' ),
				    'desc' => __( 'Highly dedicated support team are assigned for your help. Try this today.', 'country-inn' ),
				    'free'  => __('Second', 'country-inn'),
				    'pro'   => __('Dedicated With High Priority', 'country-inn'),
			    )

		    ),
		);

		Country_Inn_About::init( $config );
	}

endif;

add_action( 'after_setup_theme', 'country_inn_about_setup' );
